//LabPlot : SpreadsheetPropertiesDialog.h

#ifndef SPREADSHEETPROPERTIESDIALOG_H
#define SPREADSHEETPROPERTIESDIALOG_H

#include <qfont.h>
#include <qcheckbox.h>
#include <qtable.h>
#include "Dialog.h"

class SpreadsheetPropertiesDialog: public Dialog
{
	Q_OBJECT
public:
	SpreadsheetPropertiesDialog(MainWin *mw, QTable *t, QString name);
private:
	QTable *table;
	KComboBox *typecb, *formatcb;
	KLineEdit *labelle, *rowle;
private slots:
	void ok_clicked() { apply_clicked(); accept(); }
	void apply_clicked();
};

#endif //SPREADSHEETPROPERTIESDIALOG_H
